
History
=======

v0.1.9 / 2017-01-06
-------------------

* feat(api): add identity function
* feat(#31): add thunk function
* feat(package): add wheel package distribution
* refactor(wraps): simplify implementation
* fix(History): remove indentation

v0.1.8 / 2016-12-29
-------------------

* feat(requirements): force upgrade setuptools
* feat(#29): support async iterable and generators
* fix(docs): link to examples
* chore(travis): use Python 3.6 stable release

0.1.7 / 2016-12-18
------------------

* feat(#26): add curry function.

0.1.6 / 2016-12-11
------------------

* feat(pipe): isolate pipe operator overload code
* refactor: decorator and util functions
* feat(#11): timeout limit context manager.
* refactor(core): several minor refactors
* fix(docs): comment out latex sphinx settings
* fix(docs): use current package version
* Documentation examples improvements (#27)
* feat(history): update
* feat: add pool length magic method

0.1.5 (2016-12-04)
------------------

* fix(#25): allow empty iterables in iterators functions, such as ``map``, ``filter``, ``reduce``.

0.1.4 (2016-11-28)
------------------

* fix(#24): explicitly pass loop instance to ``asyncio.wait``.

0.1.3 (2016-10-27)
------------------

* feat(#17): add ``flat_map`` function.
* feat(#18): add pipeline-style operator overloading composition.

0.1.2 (2016-10-25)
------------------

* fix(setup.py): fix pip installation.
* refactor(api): minor refactors in several functions and tests.

0.1.1 (2016-10-24)
------------------

* refactor(name): use new project name.

0.1.0 (2016-10-23)
------------------

* First version (beta)
